External Examples
=================

Here are a list of longer, more technical examples of what PyVista can do!

.. caution::

    Please note that these examples link to external websites.
    If any of these links are broken, please raise an issue on the repository.


Do you have a technical processing workflow or visualization routine you
would like to share?
If so, please consider sharing your work here by clicking the `Edit on GitHub`
button at the top of this page and adding a link to your project!




.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3D visualization for the Open Mining Format (omf)">

.. only:: html

    .. figure:: ./images/external-examples/omfvista.png
       :target: https://opengeovis.github.io/omfvista/examples/index.html

       3D visualization for the Open Mining Format (omf)


.. raw:: html

    </div>


.. toctree::
   :hidden:

   3D visualization for the Open Mining Format (omf) <https://opengeovis.github.io/omfvista/examples/index.html>









.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="3D Rendering with Discretize">

.. only:: html

    .. figure:: ./images/external-examples/discretize.png
       :target: http://discretize.simpeg.xyz/en/master/examples/plot_pyvista_laguna.html

       3D Rendering with Discretize


.. raw:: html

    </div>


.. toctree::
   :hidden:

   3D Rendering with Discretize <http://discretize.simpeg.xyz/en/master/examples/plot_pyvista_laguna.html>











.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="OpenFOAM Rendering">

.. only:: html

    .. figure:: ./images/external-examples/open-foam.png
       :target: https://pswpswpsw.github.io/posts/2018/09/blog-post-modify-vtk-openfoam/

       OpenFOAM Rendering


.. raw:: html

    </div>


.. toctree::
   :hidden:

   OpenFOAM Rendering <https://pswpswpsw.github.io/posts/2018/09/blog-post-modify-vtk-openfoam/>










.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="AeroSandbox">

.. only:: html

    .. figure:: ./images/external-examples/AeroSandbox.png
       :target: https://peterdsharpe.github.io/AeroSandbox/

       AeroSandbox


.. raw:: html

    </div>


.. toctree::
   :hidden:

   AeroSandbox <https://peterdsharpe.github.io/AeroSandbox/>








.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="FORGE Geothermal Project">

.. only:: html

    .. figure:: ./images/external-examples/forge.png
       :target: https://forge.pvgeo.org/project/index.html

       FORGE Geothermal Project


.. raw:: html

    </div>


.. toctree::
   :hidden:

   FORGE Geothermal Project <https://forge.pvgeo.org/project/index.html>










.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="PVGeo's example gallery">

.. only:: html

    .. figure:: ./images/external-examples/pvgeo.png
       :target: https://pvgeo.org/examples/index.html

       PVGeo's example gallery


.. raw:: html

    </div>


.. toctree::
   :hidden:

   PVGeo's example gallery <https://pvgeo.org/examples/index.html>













.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="TetGen's example gallery">

.. only:: html

    .. figure:: ./images/external-examples/tetgen.png
       :target: http://tetgen.pyvista.org/examples/index.html

       TetGen's example gallery


.. raw:: html

    </div>


.. toctree::
   :hidden:

   TetGen's example gallery <http://tetgen.pyvista.org/examples/index.html>








.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="PyMeshFix's example gallery">

.. only:: html

    .. figure:: ./images/external-examples/pymeshfix.png
       :target: http://pymeshfix.pyvista.org/examples/index.html

       PyMeshFix's example gallery


.. raw:: html

    </div>


.. toctree::
   :hidden:

   PyMeshFix's example gallery <http://pymeshfix.pyvista.org/examples/index.html>









.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Orvisu Demo Application">

.. only:: html

    .. figure:: ./images/external-examples/orvisu.gif
       :target: https://github.com/BartheG/Orvisu

       Orvisu Demo Application


.. raw:: html

    </div>


.. toctree::
   :hidden:

   Orvisu Demo Application <https://github.com/BartheG/Orvisu>






.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="FLEM: A diffusive landscape evolution model">

.. only:: html

    .. figure:: ./images/external-examples/flem.png
       :target: https://github.com/johnjarmitage/flem

       FLEM: A diffusive landscape evolution model


.. raw:: html

    </div>


.. toctree::
   :hidden:

   FLEM: diffusive landscape evolution model <https://github.com/johnjarmitage/flem>







.. raw:: html

    <div style='clear:both'></div>
